# docassemble.ALMassachusetts

A docassemble extension of the AssemblyLine project that provides a foundation of Massachusetts-specific data, functionality, and questions.

## Author

Suffolk Law School Legal Innovation and Technology Lab
